4.5. umbra.components.addons.tcpServerUi.tcpServerUi — Umbra 1.0.9 documentation

# 4.5. umbra.components.addons.tcpServerUi.tcpServerUi

tcpServerUi.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `TCPServerUi` Component Interface class and others helper objects.

Others:

## 4.5.1. Module Attributes

`umbra.components.addons.tcpServerUi.tcpServerUi.` `LOGGER`

`umbra.components.addons.tcpServerUi.tcpServerUi.` `COMPONENT_UI_FILE`

## 4.5.2. Classes

class `umbra.components.addons.tcpServerUi.tcpServerUi.` `RequestsStackDataHandler`(request, client_address, server)

  Bases: `SocketServer.BaseRequestHandler`

  Defines the default requests handler.

  `handle`()

    Reimplements the `SocketServer.BaseRequestHandler.handle()` method.

    Returns: | Method success.
    Return type: | bool

class `umbra.components.addons.tcpServerUi.tcpServerUi.` `TCPServerUi`(parent=None, name=None, *args, **kwargs)

  Bases: `manager.qwidgetComponent.QWidgetComponent`

  Defines the `umbra.components.factory.tcpServerUi.tcpServerUi` Component Interface class.
  It provides various methods to operate the TCP Server.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. name (unicode) – Component name. *args (*) – Arguments. **kwargs (**) – Keywords arguments.

  `engine`

    Property for self.__engine attribute.

    Returns: | self.__engine.
    Return type: | QObject

  `settings`

    Property for self.__settings attribute.

    Returns: | self.__settings.
    Return type: | QSettings

  `settingsSection`

    Property for self.__settingsSection attribute.

    Returns: | self.__settingsSection.
    Return type: | unicode

  `preferencesManager`

    Property for self.__preferencesManager attribute.

    Returns: | self.__preferencesManager.
    Return type: | QWidget

  `tcpServer`

    Property for self.__tcpServer attribute.

    Returns: | self.__tcpServer.
    Return type: | QWidget

  `address`

    Property for self.__address attribute.

    Returns: | self.__address.
    Return type: | unicode

  `port`

    Property for self.__port attribute.

    Returns: | self.__port.
    Return type: | int

  `activate`(engine)

    Activates the Component.

    Parameters: | engine (QObject) – Engine to attach the Component to.
    Returns: | Method success.
    Return type: | bool

  `deactivate`()

    Deactivates the Component.

    Returns: | Method success.
    Return type: | bool

  `initializeUi`()

    Initializes the Component ui.

    Returns: | Method success.
    Return type: | bool

  `uninitializeUi`()

    Uninitializes the Component ui.

    Returns: | Method success.
    Return type: | bool

  `addWidget`()

    Adds the Component Widget to the engine.

    Returns: | Method success.
    Return type: | bool

  `removeWidget`()

    Removes the Component Widget from the engine.

    Returns: | Method success.
    Return type: | bool

  `onStartup`()

    Defines the slot triggered on Framework startup.

  `onClose`()

    Defines the slot triggered on Framework close.

  `startTcpServer`(port)

    Starts the TCP server using given port.

    Parameters: | port (int) – Port.
    Returns: | Method success.
    Return type: | bool

  `stopTcpServer`()

    Stops the TCP server.

    Returns: | Method success.
    Return type: | bool